@@ -1,16 +1,21 @@
 
 # returns a simplified parms object mainly useful for person ability estimation
-# parms can be enorm prms or a parms object
+# parms can be data frame or a parms object
 #
 # returns list: a, b, design (including first and last), items(including first and last)
 simplify_parms = function(parms, design=NULL, use_draw=NULL, collapse_b=FALSE)
 {
-  if(!is.null(design) && !('booklet_id' %in% colnames(design)))
-    design = mutate(design, booklet_id='all_items')
-  
   check_df(design, 'item_id', nullable=TRUE)
+  if(!is.null(design))
+  {
+    if(!('booklet_id' %in% colnames(design)))
+      design$booklet_id='all_items'
+    design = design[,c('booklet_id','item_id')]
+  }
+  
   if(inherits(parms, 'mst_enorm') && !'design' %in% names(parms$inputs))
   {
+    # to do: warnign oid? wanneer kan mst designveilig worden gebruikt?
     if(is.null(design))
       design = lapply(parms$inputs$bkList,function(bk) tibble(item_id=bk$items)) %>%
         bind_rows(.id='booklet_id')
@@ -33,6 +38,9 @@ simplify_parms = function(parms, design=NULL, use_draw=NULL, collapse_b=FALSE)
     {
       b = parms$est$b
     } 
+    
+    fl = parms$inputs$ssI[,c('item_id','first','last')]
+    
     if(is.null(design))
     {
       design = parms$inputs$design
@@ -46,7 +54,7 @@ simplify_parms = function(parms, design=NULL, use_draw=NULL, collapse_b=FALSE)
         print(setdiff(as.character(old_itm), levels(parms$inputs$ssI$item_id)))
         stop('items without parameters') 
       }
-      design = inner_join(design, parms$inputs$ssI[,c('item_id','first','last')], by='item_id')
+      design = inner_join(design, fl, by='item_id')
     }
   } else
   {
@@ -78,7 +86,7 @@ simplify_parms = function(parms, design=NULL, use_draw=NULL, collapse_b=FALSE)
     }
   }
   
-  list(a=a,b=b,design=design)
+  list(a=a, b=b, design=design, items = fl)
 }
 
 
@@ -244,7 +252,7 @@ beta2eta_ <-function(a, beta, first, last)
     {
       for (j in (first[i]+1):last[i]) 
       {
-        eta[j] = eta[j] + beta[j-1]*a[j-1]
+        eta[j] = eta[j] + beta[first[i]]*a[first[i]]
         for (g in (first[i]+1):j)
         {
           eta[j] = eta[j] + beta[g]*(a[g]-a[g-1])
